/*******************************************************************************
* File Name: GNDL.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "GNDL.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 GNDL__PORT == 15 && ((GNDL__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: GNDL_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void GNDL_Write(uint8 value) 
{
    uint8 staticBits = (GNDL_DR & (uint8)(~GNDL_MASK));
    GNDL_DR = staticBits | ((uint8)(value << GNDL_SHIFT) & GNDL_MASK);
}


/*******************************************************************************
* Function Name: GNDL_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  GNDL_DM_STRONG     Strong Drive 
*  GNDL_DM_OD_HI      Open Drain, Drives High 
*  GNDL_DM_OD_LO      Open Drain, Drives Low 
*  GNDL_DM_RES_UP     Resistive Pull Up 
*  GNDL_DM_RES_DWN    Resistive Pull Down 
*  GNDL_DM_RES_UPDWN  Resistive Pull Up/Down 
*  GNDL_DM_DIG_HIZ    High Impedance Digital 
*  GNDL_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void GNDL_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(GNDL_0, mode);
}


/*******************************************************************************
* Function Name: GNDL_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro GNDL_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 GNDL_Read(void) 
{
    return (GNDL_PS & GNDL_MASK) >> GNDL_SHIFT;
}


/*******************************************************************************
* Function Name: GNDL_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 GNDL_ReadDataReg(void) 
{
    return (GNDL_DR & GNDL_MASK) >> GNDL_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(GNDL_INTSTAT) 

    /*******************************************************************************
    * Function Name: GNDL_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 GNDL_ClearInterrupt(void) 
    {
        return (GNDL_INTSTAT & GNDL_MASK) >> GNDL_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
