/*******************************************************************************
* File Name: GNDR.h  
* Version 2.10
*
* Description:
*  This file containts Control Register function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GNDR_H) /* Pins GNDR_H */
#define CY_PINS_GNDR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GNDR_aliases.h"

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5A)
    #error Component cy_pins_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5A) */

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GNDR__PORT == 15 && ((GNDR__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

void    GNDR_Write(uint8 value) ;
void    GNDR_SetDriveMode(uint8 mode) ;
uint8   GNDR_ReadDataReg(void) ;
uint8   GNDR_Read(void) ;
uint8   GNDR_ClearInterrupt(void) ;


/***************************************
*           API Constants        
***************************************/

/* Drive Modes */
#define GNDR_DM_ALG_HIZ         PIN_DM_ALG_HIZ
#define GNDR_DM_DIG_HIZ         PIN_DM_DIG_HIZ
#define GNDR_DM_RES_UP          PIN_DM_RES_UP
#define GNDR_DM_RES_DWN         PIN_DM_RES_DWN
#define GNDR_DM_OD_LO           PIN_DM_OD_LO
#define GNDR_DM_OD_HI           PIN_DM_OD_HI
#define GNDR_DM_STRONG          PIN_DM_STRONG
#define GNDR_DM_RES_UPDWN       PIN_DM_RES_UPDWN

/* Digital Port Constants */
#define GNDR_MASK               GNDR__MASK
#define GNDR_SHIFT              GNDR__SHIFT
#define GNDR_WIDTH              1u


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GNDR_PS                     (* (reg8 *) GNDR__PS)
/* Data Register */
#define GNDR_DR                     (* (reg8 *) GNDR__DR)
/* Port Number */
#define GNDR_PRT_NUM                (* (reg8 *) GNDR__PRT) 
/* Connect to Analog Globals */                                                  
#define GNDR_AG                     (* (reg8 *) GNDR__AG)                       
/* Analog MUX bux enable */
#define GNDR_AMUX                   (* (reg8 *) GNDR__AMUX) 
/* Bidirectional Enable */                                                        
#define GNDR_BIE                    (* (reg8 *) GNDR__BIE)
/* Bit-mask for Aliased Register Access */
#define GNDR_BIT_MASK               (* (reg8 *) GNDR__BIT_MASK)
/* Bypass Enable */
#define GNDR_BYP                    (* (reg8 *) GNDR__BYP)
/* Port wide control signals */                                                   
#define GNDR_CTL                    (* (reg8 *) GNDR__CTL)
/* Drive Modes */
#define GNDR_DM0                    (* (reg8 *) GNDR__DM0) 
#define GNDR_DM1                    (* (reg8 *) GNDR__DM1)
#define GNDR_DM2                    (* (reg8 *) GNDR__DM2) 
/* Input Buffer Disable Override */
#define GNDR_INP_DIS                (* (reg8 *) GNDR__INP_DIS)
/* LCD Common or Segment Drive */
#define GNDR_LCD_COM_SEG            (* (reg8 *) GNDR__LCD_COM_SEG)
/* Enable Segment LCD */
#define GNDR_LCD_EN                 (* (reg8 *) GNDR__LCD_EN)
/* Slew Rate Control */
#define GNDR_SLW                    (* (reg8 *) GNDR__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GNDR_PRTDSI__CAPS_SEL       (* (reg8 *) GNDR__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GNDR_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GNDR__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GNDR_PRTDSI__OE_SEL0        (* (reg8 *) GNDR__PRTDSI__OE_SEL0) 
#define GNDR_PRTDSI__OE_SEL1        (* (reg8 *) GNDR__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GNDR_PRTDSI__OUT_SEL0       (* (reg8 *) GNDR__PRTDSI__OUT_SEL0) 
#define GNDR_PRTDSI__OUT_SEL1       (* (reg8 *) GNDR__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GNDR_PRTDSI__SYNC_OUT       (* (reg8 *) GNDR__PRTDSI__SYNC_OUT) 


#if defined(GNDR__INTSTAT)  /* Interrupt Registers */

    #define GNDR_INTSTAT                (* (reg8 *) GNDR__INTSTAT)
    #define GNDR_SNAP                   (* (reg8 *) GNDR__SNAP)

#endif /* Interrupt Registers */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GNDR_H */


/* [] END OF FILE */
